//
//  CalloutView.m
//  TextKit
//
//  Created by Gene Whitaker on 8/1/15.
//  Copyright (c) 2015 Bombing Brain Interactive. All rights reserved.
//

#import "CalloutView.h"

#define CORNER_RADIUS_PERCENTAGE .15
#define RECTANGLE_SIZE_PERCENTAGE .8
#define BUTTON_PADDING 6.0

@interface CalloutView ()
@property (nonatomic) CGRect rectangleFrame;
@property (strong, nonatomic) UIColor *color;
@end


@implementation CalloutView

-(instancetype)initWithFrame:(CGRect)frame {
    if (self = [super initWithFrame:frame]) {
        _color = [UIColor lightGrayColor];
        _customAnchorXPosition = 0.0;
        CGSize rectSize = CGSizeMake(frame.size.width, frame.size.height*RECTANGLE_SIZE_PERCENTAGE);
        _rectangleFrame = CGRectMake(0, frame.size.height-rectSize.height, rectSize.width, rectSize.height);
    }
    return self;
}

- (void)drawRect:(CGRect)rect {
    
    //Rectangle
    CGFloat cornerRadius = self.rectangleFrame.size.height*CORNER_RADIUS_PERCENTAGE;
    UIBezierPath *rectanglePath = [UIBezierPath bezierPathWithRoundedRect:self.rectangleFrame cornerRadius:cornerRadius];
    [self.color set];
    [rectanglePath fill];
    
    ///Triangle
    UIBezierPath *trianglePath = [UIBezierPath bezierPath];
    
    //X positions
    CGFloat radiusSizeX = rectanglePath.bounds.size.width*CORNER_RADIUS_PERCENTAGE;
    CGFloat minAnchorXPosition = radiusSizeX;
    CGFloat maxAnchorXPosition = rectanglePath.bounds.size.width-radiusSizeX;
    CGFloat anchorXPosition;
    if (self.customAnchorXPosition < minAnchorXPosition) {
        anchorXPosition = minAnchorXPosition;
    }
    else if (minAnchorXPosition < self.customAnchorXPosition <= maxAnchorXPosition) {
        anchorXPosition = self.customAnchorXPosition;
    }
    else {
        anchorXPosition = maxAnchorXPosition;
    }
    
    //Y positions
    CGFloat bottomYPosition = rectanglePath.bounds.origin.y;
    CGFloat topYPosition = 0;
    
    //left point
    CGPoint startPoint = CGPointMake(radiusSizeX/2, bottomYPosition);
    [trianglePath moveToPoint:startPoint];
    
    //anchor
    CGPoint anchorPoint = CGPointMake(anchorXPosition, topYPosition);
    CGPoint controlPoint = CGPointMake(anchorXPosition, bottomYPosition);
    [trianglePath addQuadCurveToPoint:anchorPoint controlPoint:controlPoint];
    
    //right point
    CGPoint endPoint = CGPointMake(self.bounds.size.width-radiusSizeX/2, bottomYPosition);
    [trianglePath addQuadCurveToPoint:endPoint controlPoint:controlPoint];
    
    [trianglePath closePath];
    [self.color set];
    [trianglePath fill];
}

-(void)layoutSubviews {
    
    self.backgroundColor = [UIColor clearColor];
    UIButton *button = [[UIButton alloc] initWithFrame:self.rectangleFrame];
    button.tintColor = [UIColor whiteColor];
    [button setImage:[UIImage imageNamed:@"recordings_playbutton"] forState:UIControlStateNormal];
    [button setImage:[UIImage imageNamed:@"recordings_stopbutton"] forState:UIControlStateSelected];
    [button addTarget:self action:@selector(buttonAction:) forControlEvents:UIControlEventTouchUpInside];
    [self addSubview:button];
    button.selected = self.selected;
    
}

-(void)buttonAction:(UIButton*)button {
    if (self.allowsSelectedState) {
        button.selected = !button.selected;
        self.selected = button.selected;
    }
    if (self.delegate && [self.delegate respondsToSelector:@selector(calloutViewTapped:fromRect:withRange:)]) {
        [self.delegate calloutViewTapped:self fromRect:self.rectangleFrame withRange:self.range];
    }
}


@end
