//
//  CustomTextStorage.m
//  TextKit
//
//  Created by Gene Whitaker on 8/6/15.
//  Copyright (c) 2015 Bombing Brain Interactive. All rights reserved.
//

#import "CustomTextStorage.h"
#import "Constants.h"

@interface CustomTextStorage ()
@property (strong, nonatomic) NSMutableAttributedString *attributedString;
@end

@implementation CustomTextStorage

#pragma mark - properties

- (NSString *)string {
    return self.attributedString.string;
}

#pragma mark - implementation

- (instancetype)init {
    if(self = [super init]) {
        _attributedString = [[NSMutableAttributedString alloc] init];
    }
    return self;
}

-(instancetype)initWithAttributedString:(NSAttributedString *)attrStr {
    if(self = [super init]) {
    _attributedString = [attrStr mutableCopy];
    }
    return self;
}

- (NSDictionary *)attributesAtIndex:(NSUInteger)location effectiveRange:(NSRangePointer)range {
    return [self.attributedString attributesAtIndex:location effectiveRange:range];
}

- (void)replaceCharactersInRange:(NSRange)range withString:(NSString *)str {
    [self.attributedString replaceCharactersInRange:range withString:str];
    [self edited:NSTextStorageEditedCharacters range:range changeInLength:(NSInteger)str.length - (NSInteger)range.length];
}

- (void)setAttributes:(NSDictionary *)attrs range:(NSRange)range {
    [self.attributedString setAttributes:attrs range:range];
    [self edited:NSTextStorageEditedAttributes range:range changeInLength:0];
}


#pragma mark - Syntax highlighting

- (void)processEditing {
    
    // Regular expression matching "[*,*.mp4]"
    NSRegularExpression *expression = [NSRegularExpression regularExpressionWithPattern:@"\\[.*,.*\\.mp4\\]" options:0 error:NULL];
    
    // Find the regular expression in current paragraph
    NSRange paragaphRange = [self.string paragraphRangeForRange: self.editedRange];
    [expression enumerateMatchesInString:self.string options:0 range:paragaphRange usingBlock:^(NSTextCheckingResult *result, NSMatchingFlags flags, BOOL *stop) {

        //Get the current attributes where this range begins
        NSDictionary *originalAttributes = [self attributesAtIndex:result.range.location effectiveRange:nil];
        
        //Parse the matched text (remove brackets and split the remaining string by comma)
        NSString *subString = [self.string substringWithRange:NSMakeRange(result.range.location+1, result.range.length-2)];
        NSArray *components = [subString componentsSeparatedByString:@","];
        
        //Get the value we will use for AUDIO_FILE_ATTRIBUTE
        NSString *audioFile = components[1];
        
        //Create a new attributes dictionary for this new text
        NSMutableDictionary *attributes = [originalAttributes mutableCopy];
        
        //Add the AUDIO_FILE_ATTRIBUTE
        attributes[AUDIO_FILE_ATTRIBUTE] = audioFile;
        
        //Also format the title in bold and italics (if supported by the font)
        UIFont *oldFont = attributes[NSFontAttributeName];
        UIFontDescriptor *oldFontDescriptor = [oldFont fontDescriptor];
        UIFontDescriptor *italicDescriptor = [oldFontDescriptor fontDescriptorWithSymbolicTraits:(oldFontDescriptor.symbolicTraits | UIFontDescriptorTraitItalic)];
        UIFontDescriptor *boldDescriptor = [italicDescriptor fontDescriptorWithSymbolicTraits:(italicDescriptor.symbolicTraits | UIFontDescriptorTraitBold)];
        UIFont *newFont = [UIFont fontWithDescriptor:boldDescriptor size:oldFont.pointSize];
        if(newFont != nil) {
            //Add the bold italic font attribute
            attributes[NSFontAttributeName] = newFont;
        }
        
        //Create the attributed string to insert
        NSMutableAttributedString *title = [[NSMutableAttributedString alloc] initWithString:components[0] attributes:attributes];

        //Replace the matched text with our new attributed string
        [self replaceCharactersInRange:result.range withAttributedString:title];
        
    }];
    
    //Finalize changes, call delegates
    [super processEditing];
}


@end


