//
//  PageViewController.m
//  TextKit
//
//  Created by Gene Whitaker on 8/5/15.
//  Copyright (c) 2015 Bombing Brain Interactive. All rights reserved.
//

#import "PageViewController.h"
#import "ColumnTextView.h"
#import <AVFoundation/AVFoundation.h>

@interface PageViewController () <ColumnTextViewDelegate>
@property (weak, nonatomic) IBOutlet ColumnTextView *columnTextView;
@property (weak, nonatomic) IBOutlet UIImageView *exclusionView;
@property (strong, nonatomic) AVAudioPlayer *audioPlayer;
@property (nonatomic) BOOL useExclusionPath;
@end

@implementation PageViewController

#pragma mark - view lifecycle

- (void)viewDidLoad {
    [super viewDidLoad];
    self.columnTextView.delegate = self;
    self.useExclusionPath = YES;
    
}

-(void)viewWillDisappear:(BOOL)animated {
    if(self.audioPlayer) {
        [self.audioPlayer stop];
        self.audioPlayer = nil;
    }
}

-(void)viewDidLayoutSubviews {

    //Get the path of the exclusion view and pass to the column view
    if (self.useExclusionPath) {
        self.exclusionView.hidden = NO;
        CGRect exclusionRect = [self.columnTextView convertRect:self.exclusionView.bounds fromView:self.exclusionView];
        UIBezierPath *exclusionPath = [UIBezierPath bezierPathWithRect:exclusionRect];
        self.columnTextView.exclusionPaths = @[exclusionPath];
    }
    else {
        self.exclusionView.hidden = YES;
    }

}

#pragma mark - ColumnTextViewDelegate

-(void)columnTextViewDidToggleAudio:(NSString*)audioFileName on:(BOOL)on {
    
    //Stop previous audio
    if (self.audioPlayer.isPlaying) {
        [self.audioPlayer stop];
        self.audioPlayer = nil;
    }
    
    //Play or stop audio
    if (on) {
        NSArray* components = [audioFileName componentsSeparatedByString:@"."];
        NSString *path = [[NSBundle mainBundle] pathForResource:components[0] ofType:components[1]];
        self.audioPlayer = [[AVAudioPlayer alloc] initWithContentsOfURL: [[NSURL alloc] initFileURLWithPath:path] error: nil];
        self.audioPlayer.volume = .6;
        [self.audioPlayer prepareToPlay];
        [self.audioPlayer play];
    }
    
}

@end
